==> flashcam-0.1.5.tar.gz: flashcam-0.1.5/README.md <==
Project flashcam
================

`FLASk supported Http webCAM`

IN DEVELOPMENT

/Here, the merge of several ideas will form the package for easy
installable webcam surveylance via PyPI. The basic aim is to access view
to various technical devices during an experiment./

Usage screen
------------

    ... usage:
                flashcam ls
                flashcam getres [product | IDpath ]        # flashcam getres "Webcam C270"
                flashcam show [product | IDpath ] [-r res] # flashcam show  "Webcam C270"
                                                               # flashcam show  "Webcam C270"  -r 320x176

           ... cv2.V4L2 is used to avoid stuck while cap.read()

Status:
-------

-   `usbcheck` can identify the camera by `product` or `IDpath`
-   `v4l2` prove of concept - exposure/gain autotune - worked
-   `show` (imshow) was tuned, now it needs a rewrite with `base_camera`
-   `flask` interface is responsive
-   `web.py` must be same with `flask5000` option
-   `base_camera` (with greenlets) and `real_camera` modules work with
    flask
    -   initialized with `recommend`
    -   never-stopping (unlike the original version)
    -   more tricky tuning classmethod andstaticmethod was needed
-   `flask` interface works
-   gray frame is sent when no camera through web
-   autostarts (threading) with `wget -u -p -O /dev/null` for 3 sec. and
    then kill
-   properly taken `product` in `real_cam`
-   rewrite proprerly for gunicorn (no gevent; --w 1 --t 5+); flashcam
    flask
-   with automatic wget to start, with debugprint for gunicorn too
-   !! `product` may not work now

To see next
-----------

-   show on screen rewrite
-   frame decoration classes
-   v4l2

V4l2
----

Camera sometimes needs to tune at dark conditions. Nicely done project
to call `v4l2-ctrl` was used

Identification of a camera
--------------------------

Several devices on USB, replugging or an built-in webcam of the notebok
or sevral dev/video devices per CAM can make identification via
`/dev/video` more difficult.

==> flashcam-0.3.22.tar.gz: flashcam-0.3.22/README.md <==
Project flashcam
================

`FLASk supported Http webCAM`

IN DEVELOPMENT

/Here, the merge of several ideas will form the package for easy
installable webcam surveylance via PyPI. The basic aim is to access view
to various technical devices during an experiment./

Usage screen
------------

    ... usage:
                flashcam ls
                flashcam getres [product | IDpath ]        # flashcam getres "Webcam C270"
                flashcam show [product | IDpath ] [-r res] # flashcam show  "Webcam C270"
                                                               # flashcam show  "Webcam C270"  -r 320x176

           ... cv2.V4L2 is used to avoid stuck while cap.read()

Status:
-------

-   `usbcheck` can identify the camera by `product` or `IDpath`
-   `v4l2` prove of concept - exposure/gain autotune - worked
-   `show` (imshow) was tuned, now it needs a rewrite with `base_camera`
-   `flask` interface is responsive
-   `web.py` must be same with `flask5000` option
-   `base_camera` (with greenlets) and `real_camera` modules work with
    flask
    -   initialized with `recommend`
    -   never-stopping (unlike the original version)
    -   more tricky tuning classmethod andstaticmethod was needed
-   `flask` interface works
-   gray frame is sent when no camera through web
-   autostarts (threading) with `wget -u -p -O /dev/null` for 3 sec. and
    then kill
-   properly taken `product` in `real_cam`
-   rewrite proprerly for gunicorn (no gevent; --w 1 --t 5+); flashcam
    flask
-   with automatic wget to start, with debugprint for gunicorn too
-   !! `product` may not work now
-   `stream_enhancer` decorations ON
-   =detect motion basics ON -t threshold (0 - means NO)
-   three modes -a 10 -b 3 -t 100 -f \[direct\|delta\|detect\]

To see next
-----------

-   v4l2

V4l2
----

Camera sometimes needs to tune at dark conditions. Nicely done project
to call `v4l2-ctrl` was used

Identification of a camera
--------------------------

Several devices on USB, replugging or an built-in webcam of the notebok
or sevral dev/video devices per CAM can make identification via
`/dev/video` more difficult.
